@@ -6,8 +6,21 @@ module Language.JavaScript.Parser
        , PA.parseFileUtf8
        , PA.showStripped
        , PA.showStrippedMaybe
-       , JSNode(..)
-       , Node(..)
+       -- * AST elements
+       , JSExpression (..)
+       , JSAnnot (..)
+       , JSBinOp (..)
+       , JSBlock (..)
+       , JSUnaryOp (..)
+       , JSSemi (..)
+       , JSAssignOp (..)
+       , JSTryCatch (..)
+       , JSTryFinally (..)
+       , JSStatement (..)
+       , JSSwitchParts (..)
+       , JSAST(..)
+
+
        , CommentAnnotation(..)
        -- , ParseError(..)
        -- Source locations
@@ -16,13 +29,13 @@ module Language.JavaScript.Parser
        -- * Pretty Printing
        , renderJS
        , renderToString
+       , renderToText
        ) where
 
 
 import Language.JavaScript.Parser.AST
 import Language.JavaScript.Parser.Token
 import qualified Language.JavaScript.Parser.Parser as PA
-
 import Language.JavaScript.Parser.SrcLocation
 import Language.JavaScript.Pretty.Printer
 
